@@ -3,18 +3,21 @@ Main interface for forecast service type definitions.
 
 Usage::
 
-    from mypy_boto3.forecast.type_defs import CategoricalParameterRangeTypeDef
+    ```python
+    from mypy_boto3_forecast.type_defs import CategoricalParameterRangeTypeDef
 
     data: CategoricalParameterRangeTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
